@@ -121,8 +121,12 @@ ReadGrib <- function(file.name, levels, variables, domain = NULL, file.type = "g
             match.str, sep = "")
         
         #Get the data from the grib file in CSV format
-        csv.str <- system(wg2.str, intern = TRUE)
-    
+        if(Sys.info()[["sysname"]] == "Windows") {
+            csv.str <- shell(wg2.str, intern = TRUE)        
+        } else {
+            csv.str <- system(wg2.str, intern = TRUE)
+        } 
+
         #HERE IS THE EXTRACTION
         model.data.vector <- strsplit(paste(gsub("\"", "", csv.str), collapse = ","), split = ",")[[1]]
         chunk.inds <- seq(1, length(model.data.vector) - 6, by = 7)
